# -*- coding: utf-8 -*-

"""
   wegene.Controllers.AthletigenController

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
import requests

from wegene.APIHelper import APIHelper
from wegene.Configuration import Configuration
from wegene.APIException import APIException
from wegene.Models.Haplogroup import Haplogroup

class Haplogroups(object):


    """A Controller to access Endpoints in the WeGeneAPILib API."""

    def get_haplogroups(self,
                    profile_id):
        """Does a POST request to /haplgroups/result/{profile_id}.

        Athletigen based on genetic information

        Args:
            profile_id (string): Genetic profile id

        Returns:
            Report: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """
        # The base uri for api requests
        query_builder = Configuration.BASE_URI

        # Prepare query string for API call
        query_builder += "/haplogroups/result/{profile_id}"

        # Process optional template parameters
        query_builder = APIHelper.append_url_with_template_parameters(query_builder, {
            "profile_id": profile_id
        })

        # Validate and preprocess url
        query_url = APIHelper.clean_url(query_builder)

        # Prepare headers
        headers = {

            "Authorization": "Bearer " + Configuration.o_auth_access_token,
            "user-agent": "WeGene SDK",
            "accept": "application/json",

        }

        # Prepare parameters
        parameters = {
        }

        # Prepare and invoke the API call request to fetch the response
        response = requests.post(query_url, headers=headers, data=parameters)

        # Error handling using HTTP status codes
        if response.status_code < 200 or response.status_code > 206:  # 200 = HTTP OK
            raise APIException("HTTP Response Not OK", response.status_code, response.json())

        # Try to cast response to desired type
        if isinstance(response.json(), dict):
            # Response is already in a dictionary, return the object
            try:
                return Haplogroup(**response.json())
            except TypeError:
                raise APIException("Invalid JSON returned", response.status_code, response.json())

        # If we got here then an error occured while trying to parse the response
        raise APIException("Invalid JSON returned", response.status_code, response.json())



from wegene.Models.User import *
from wegene.Models.Profile import *
from wegene.Models.GenotypesModel import *
from wegene.Models.Report import *
from wegene.Models.GenotypeModel import *
from wegene.Models.AncestryArea import *
from wegene.Models.AncestryBlock import *
from wegene.Models.AncestryComposition import *
from wegene.Models.Haplogroup import *
from wegene.Models.Demographic import *



# -*- coding: utf-8 -*-

"""
   wegene.Models.AncestryArea

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
from wegene.APIHelper import APIHelper


class AncestryArea(object):

    """Implementation of the 'ancestry area' model.

    User ancestry composition areas information

    Attributes:
        uygur (string): composition component
        ny (string): composition component
        finnish_russian (string): composition component
        iranian (string): composition component
        dai (string): composition component
        spanish (string): composition component
        han_southern (string): composition component
        han_northern (string): composition component
        somali (string): composition component
        tungus (string): composition component
        sardinian (string): composition component
        mayan (string): composition component
        mongolian (string): composition component
        egyptian (string): composition component
        pima (string): composition component
        gaoshan (string): composition component
        lahu (string): composition component
        cambodian (string): composition component
        korean (string): composition component
        french (string): composition component
        english (string): composition component
        balkan (string): composition component
        sindhi (string): composition component
        papuan (string): composition component
        hungarian (string): composition component
        kinh (string): composition component
        japanese (string): composition component
        eskimo (string): composition component
        saudi (string): composition component
        mbuti (string): composition component
        she (string): composition component
        tibetan (string): composition component
        yoruba (string): composition component
        bantusa (string): composition component
        ashkenazi (string): composition component
        mala (string): composition component
        yakut (string): composition component
        bengali (string): composition component
        thai (string): composition component
        kyrgyz (string): composition component
        uzbek (string): composition component
        miao_yao (string): composition component

    """

    def __init__(self,
                 **kwargs):
        """Constructor for the Report class

        Args:
            **kwargs: Keyword Arguments in order to initialise the
                object. Any of the attributes in this object are able to
                be set through the **kwargs of the constructor. The values
                that can be supplied and their types are as follows::

                    uygur -- string -- composition component
                    ny -- string -- composition component
                    finnish_russian -- string -- composition component
                    iranian -- string -- composition component
                    dai -- string -- composition component
                    spanish -- string -- composition component
                    han_southern -- string -- composition component
                    han_northern -- string -- composition component
                    somali -- string -- composition component
                    tungus -- string -- composition component
                    sardinian -- string -- composition component
                    mayan -- string -- composition component
                    mongolian -- string -- composition component
                    egyptian -- string -- composition component
                    pima -- string -- composition component
                    gaoshan -- string -- composition component
                    lahu -- string -- composition component
                    cambodian -- string -- composition component
                    korean -- string -- composition component
                    french -- string -- composition component
                    english -- string -- composition component
                    balkan -- string -- composition component
                    sindhi -- string -- composition component
                    papuan -- string -- composition component
                    hungarian -- string -- composition component
                    kinh -- string -- composition component
                    japanese -- string -- composition component
                    eskimo -- string -- composition component
                    saudi -- string -- composition component
                    mbuti -- string -- composition component
                    she -- string -- composition component
                    tibetan -- string -- composition component
                    yoruba -- string -- composition component
                    bantusa -- string -- composition component
                    ashkenazi -- string -- composition component
                    mala -- string -- composition component
                    yakut -- string -- composition component
                    bengali -- string -- composition component
                    thai -- string -- composition component
                    kyrgyz -- string -- composition component
                    uzbek -- string -- composition component
                    miao_yao -- string -- composition component

        """
        # Set all of the parameters to their default values
        self.uygur = None
        self.ny = None
        self.finnish_russian = None
        self.iranian = None
        self.dai = None
        self.spanish = None
        self.han_southern = None
        self.han_northern = None
        self.somali = None
        self.tungus = None
        self.sardinian = None
        self.mayan = None
        self.mongolian = None
        self.egyptian = None
        self.pima = None
        self.gaoshan = None
        self.lahu = None
        self.cambodian = None
        self.korean = None
        self.french = None
        self.english = None
        self.balkan = None
        self.sindhi = None
        self.papuan = None
        self.hungarian = None
        self.kinh = None
        self.japanese = None
        self.eskimo = None
        self.saudi = None
        self.mbuti = None
        self.she = None
        self.tibetan = None
        self.yoruba = None
        self.bantusa = None
        self.ashkenazi = None
        self.mala = None
        self.yakut = None
        self.bengali = None
        self.thai = None
        self.kyrgyz = None
        self.uzbek = None
        self.miao_yao = None

        # Create a mapping from API property names to Model property names
        replace_names = {
            "uygur": "uygur",
            "ny": "ny",
            "finnish_russian": "finnish_russian",
            "iranian": "iranian",
            "dai": "dai",
            "spanish": "spanish",
            "han_southern": "han_southern",
            "han_northern": "han_northern",
            "somali": "somali",
            "tungus": "tungus",
            "sardinian": "sardinian",
            "mayan": "mayan",
            "mongolian": "mongolian",
            "egyptian": "egyptian",
            "pima": "pima",
            "gaoshan": "gaoshan",
            "lahu": "lahu",
            "cambodian": "cambodian",
            "korean": "korean",
            "french": "french",
            "english": "english",
            "balkan": "balkan",
            "sindhi": "sindhi",
            "papuan": "papuan",
            "hungarian": "hungarian",
            "kinh": "kinh",
            "japanese": "japanese",
            "eskimo": "eskimo",
            "saudi": "saudi",
            "mbuti": "mbuti",
            "she": "she",
            "tibetan": "tibetan",
            "yoruba": "yoruba",
            "bantusa": "bantusa",
            "ashkenazi": "ashkenazi",
            "mala": "mala",
            "yakut": "yakut",
            "bengali": "bengali",
            "thai": "thai",
            "kyrgyz": "kyrgyz",
            "uzbek": "uzbek",
            "miao_yao": "miao_yao"
        }

        # Parse all of the Key-Value arguments
        if kwargs is not None:
            for key in kwargs:
                # Only add arguments that are actually part of this object
                if key in replace_names:
                    setattr(self, replace_names[key], kwargs[key])

            # Other objects also need to be initialised properly
            if "result" in kwargs:
                self.result = GenotypesModel(**kwargs["result"])

    def resolve_names(self):
        """Creates a dictionary representation of this object.

        This method converts an object to a dictionary that represents the
        format that the model should be in when passed into an API Request.
        Because of this, the generated dictionary may have different
        property names to that of the model itself.

        Returns:
            dict: The dictionary representing the object.

        """
        # Create a mapping from Model property names to API property names
        replace_names = {
            "uygur": "uygur",
            "ny": "ny",
            "finnish_russian": "finnish_russian",
            "iranian": "iranian",
            "dai": "dai",
            "spanish": "spanish",
            "han_southern": "han_southern",
            "han_northern": "han_northern",
            "somali": "somali",
            "tungus": "tungus",
            "sardinian": "sardinian",
            "mayan": "mayan",
            "mongolian": "mongolian",
            "egyptian": "egyptian",
            "pima": "pima",
            "gaoshan": "gaoshan",
            "lahu": "lahu",
            "cambodian": "cambodian",
            "korean": "korean",
            "french": "french",
            "english": "english",
            "balkan": "balkan",
            "sindhi": "sindhi",
            "papuan": "papuan",
            "hungarian": "hungarian",
            "kinh": "kinh",
            "japanese": "japanese",
            "eskimo": "eskimo",
            "saudi": "saudi",
            "mbuti": "mbuti",
            "she": "she",
            "tibetan": "tibetan",
            "yoruba": "yoruba",
            "bantusa": "bantusa",
            "ashkenazi": "ashkenazi",
            "mala": "mala",
            "yakut": "yakut",
            "bengali": "bengali",
            "thai": "thai",
            "kyrgyz": "kyrgyz",
            "uzbek": "uzbek",
            "miao_yao": "miao_yao",
        }

        retval = dict()

        return APIHelper.resolve_names(self, replace_names, retval)



# -*- coding: utf-8 -*-

"""
   wegene.Models.AncestryBlock

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
from wegene.APIHelper import APIHelper


class AncestryBlock(object):

    """Implementation of the 'ancestry block' model.

    User ancestry composition blocks information

    Attributes:
        african (string): composition component
        middle_eastern (string): composition component
        ne_asian (string): composition component
        se_asian (string): composition component
        chinese_nation (string): composition component
        central_asian (string): composition component
        european (string): composition component
        american (string): composition component
        south_asian (string): composition component
        oceanian (string): composition component

    """

    def __init__(self,
                 **kwargs):
        """Constructor for the Report class

        Args:
            **kwargs: Keyword Arguments in order to initialise the
                object. Any of the attributes in this object are able to
                be set through the **kwargs of the constructor. The values
                that can be supplied and their types are as follows::

                    african -- string -- composition component
                    middle_eastern -- string -- composition component
                    ne_asian -- string -- composition component
                    se_asian -- string -- composition component
                    chinese_nation -- string -- composition component
                    central_asian -- string -- composition component
                    european -- string -- composition component
                    american -- string -- composition component
                    south_asian -- string -- composition component
                    oceanian -- string -- composition component

        """
        # Set all of the parameters to their default values
        self.african = None
        self.middle_eastern = None
        self.ne_asian = None
        self.se_asian = None
        self.chinese_nation = None
        self.central_asian = None
        self.european = None
        self.american = None
        self.south_asian = None
        self.oceanian = None

        # Create a mapping from API property names to Model property names
        replace_names = {
            "african": "african",
            "middle_eastern": "middle_eastern",
            "ne_asian": "ne_asian",
            "se_asian": "se_asian",
            "chinese_nation": "chinese_nation",
            "central_asian": "central_asian",
            "european": "european",
            "american": "american",
            "south_asian": "south_asian",
            "oceanian": "oceanian",
        }

        # Parse all of the Key-Value arguments
        if kwargs is not None:
            for key in kwargs:
                # Only add arguments that are actually part of this object
                if key in replace_names:
                    setattr(self, replace_names[key], kwargs[key])

            # Other objects also need to be initialised properly
            if "result" in kwargs:
                self.result = GenotypesModel(**kwargs["result"])

    def resolve_names(self):
        """Creates a dictionary representation of this object.

        This method converts an object to a dictionary that represents the
        format that the model should be in when passed into an API Request.
        Because of this, the generated dictionary may have different
        property names to that of the model itself.

        Returns:
            dict: The dictionary representing the object.

        """
        # Create a mapping from Model property names to API property names
        replace_names = {
            "african": "african",
            "middle_eastern": "middle_eastern",
            "ne_asian": "ne_asian",
            "se_asian": "se_asian",
            "chinese_nation": "chinese_nation",
            "central_asian": "central_asian",
            "european": "european",
            "american": "american",
            "south_asian": "south_asian",
            "oceanian": "oceanian",
        }

        retval = dict()

        return APIHelper.resolve_names(self, replace_names, retval)



# -*- coding: utf-8 -*-

"""
   wegene.Models.AncestryComposition

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
from wegene.APIHelper import APIHelper
from wegene.Models.AncestryBlock import AncestryBlock
from wegene.Models.AncestryArea import AncestryArea


class AncestryComposition(object):

    """Implementation of the 'ancestry composition' model.

    Model for user ancestry composition information

    Attributes:
        data_hash (string): WeGene data profile id
        block (AncestryBlock): Ancestry composition by blocks
        area (AncestryArea): Ancestry composition by areas
        update_time (string): Last updated time

    """

    def __init__(self,
                 **kwargs):
        """Constructor for the User class

        Args:
            **kwargs: Keyword Arguments in order to initialise the
                object. Any of the attributes in this object are able to
                be set through the **kwargs of the constructor. The values
                that can be supplied and their types are as follows::

                    data_hash -- string -- WeGene data profile id
                    block -- AncestryBlock) -- Ancestry composition by blocks
                    area -- AncestryArea -- Ancestry composition by areas
                    update_time -- string -- Last updated time


        """
        # Set all of the parameters to their default values
        self.data_hash = None
        self.block = None
        self.area = None
        self.update_time = None

        # Create a mapping from API property names to Model property names
        replace_names = {
            "data_hash": "data_hash",
            "block": "block",
            "area": "area",
            "update_time": "update_time",
        }

        # Parse all of the Key-Value arguments
        if kwargs is not None:
            for key in kwargs:
                # Only add arguments that are actually part of this object
                if key in replace_names:
                    setattr(self, replace_names[key], kwargs[key])

            # Other objects also need to be initialised properly
            if "block" in kwargs:
                self.block = AncestryBlock(**kwargs["block"])

            if "area" in kwargs:
                self.area = AncestryArea(**kwargs["area"])

    def resolve_names(self):
        """Creates a dictionary representation of this object.

        This method converts an object to a dictionary that represents the
        format that the model should be in when passed into an API Request.
        Because of this, the generated dictionary may have different
        property names to that of the model itself.

        Returns:
            dict: The dictionary representing the object.

        """
        # Create a mapping from Model property names to API property names
        replace_names = {
            "data_hash": "data_hash",
            "block": "block",
            "area": "area",
            "update_time": "update_time",
        }

        retval = dict()

        return APIHelper.resolve_names(self, replace_names, retval)



from wegene.Controllers.WeGeneUser import *
from wegene.Controllers.Allele import *
from wegene.Controllers.Health import *
from wegene.Controllers.Athletigen import *
from wegene.Controllers.Risk import *
from wegene.Controllers.Haplogroups import *
from wegene.Controllers.Ancestry import *
from wegene.Controllers.Demographics import *



# -*- coding: utf-8 -*-

"""
   wegene.Configuration

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""

class Configuration :
    # The base Uri for API calls
    BASE_URI = "https://api.wegene.com"

    # The OAuth 2.0 access token to be set before API calls
    # TODO: Replace the o_auth_access_token with an appropriate value
    o_auth_access_token = "TODO: Replace"



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages


long_description = 'WeGene Python SDK. For details check https://api.wegene.com'

setup(
    name="wegene",
    version="0.1.0",
    url="https://github.com/xraywu/wegene-python-sdk",
    description="WeGene SDK for Python",
    license="MIT",
    author="Eddie Wu",
    author_email="xrayxiaoli@gmail.com",
    package_dir={ 'wegene': 'wegene' },
    packages=find_packages(),
    install_requires=[
        "requests==2.21.0",
        "jsonpickle==0.7.1",
    ],
    long_description=long_description,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
    ]
)



# -*- coding: utf-8 -*-

"""
   wegene.Models.Profile

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
from wegene.APIHelper import APIHelper


class Profile(object):

    """Implementation of the 'profile' model.

    Genetic profile available for Wegene User

    Attributes:
        id (string): Genetic profile Id
        format (string): Genetic profile format type
        sex (string): Sex
        name (string): User real name associated with the profile

    """

    def __init__(self,
                 **kwargs):
        """Constructor for the Profile class

        Args:
            **kwargs: Keyword Arguments in order to initialise the
                object. Any of the attributes in this object are able to
                be set through the **kwargs of the constructor. The values
                that can be supplied and their types are as follows::

                    id -- string -- Sets the attribute id
                    format -- string -- Sets the attribute format
                    sex -- string -- Sets the attribute sex
                    name -- string -- Sets the attribute name

        """
        # Set all of the parameters to their default values
        self.id = None
        self.format = None
        self.sex = None
        self.name = None

        # Create a mapping from API property names to Model property names
        replace_names = {
            "id": "id",
            "format": "format",
            "sex": "sex",
            "name": "name",
        }

        # Parse all of the Key-Value arguments
        if kwargs is not None:
            for key in kwargs:
                # Only add arguments that are actually part of this object
                if key in replace_names:
                    setattr(self, replace_names[key], kwargs[key])

    def resolve_names(self):
        """Creates a dictionary representation of this object.

        This method converts an object to a dictionary that represents the
        format that the model should be in when passed into an API Request.
        Because of this, the generated dictionary may have different
        property names to that of the model itself.

        Returns:
            dict: The dictionary representing the object.

        """
        # Create a mapping from Model property names to API property names
        replace_names = {
            "id": "id",
            "format": "format",
            "sex": "sex",
            "name": "name",
        }

        retval = dict()

        return APIHelper.resolve_names(self, replace_names, retval)



# -*- coding: utf-8 -*-

"""
   wegene.Models.User

   This file was automatically generated by APIMATIC BETA v2.0 on 02/22/2016
"""
from wegene.APIHelper import APIHelper
from wegene.Models.Profile import Profile


class User(object):

    """Implementation of the 'user' model.

    Model for user information

    Attributes:
        id (string): Unique Wegene Id
        profiles (list of Profile): Available genetic profile data in array
        email (string): User email at Wegene

    """

    def __init__(self,
                 **kwargs):
        """Constructor for the User class

        Args:
            **kwargs: Keyword Arguments in order to initialise the
                object. Any of the attributes in this object are able to
                be set through the **kwargs of the constructor. The values
                that can be supplied and their types are as follows::

                    id -- string -- Sets the attribute id
                    profiles -- list of Profile -- Sets the attribute profiles
                    email -- string -- Sets the attribute email

        """
        # Set all of the parameters to their default values
        self.id = None
        self.profiles = None
        self.email = None

        # Create a mapping from API property names to Model property names
        replace_names = {
            "id": "id",
            "profiles": "profiles",
            "email": "email",
        }

        # Parse all of the Key-Value arguments
        if kwargs is not None:
            for key in kwargs:
                # Only add arguments that are actually part of this object
                if key in replace_names:
                    setattr(self, replace_names[key], kwargs[key])

            # Other objects also need to be initialised properly
            if "profiles" in kwargs:
                # Parameter is an array, so we need to iterate through it
                self.profiles = list()
                for item in kwargs["profiles"]:
                    self.profiles.append(Profile(**item))

    def resolve_names(self):
        """Creates a dictionary representation of this object.

        This method converts an object to a dictionary that represents the
        format that the model should be in when passed into an API Request.
        Because of this, the generated dictionary may have different
        property names to that of the model itself.

        Returns:
            dict: The dictionary representing the object.

        """
        # Create a mapping from Model property names to API property names
        replace_names = {
            "id": "id",
            "profiles": "profiles",
            "email": "email",
        }

        retval = dict()

        return APIHelper.resolve_names(self, replace_names, retval)
